@@ -76,7 +76,8 @@ void UpdateModel::setBackend(ResourcesUpdatesModel* updates)
 void UpdateModel::resourceHasProgressed(AbstractResource* res, qreal progress)
 {
     UpdateItem* item = itemFromResource(res);
-    Q_ASSERT(item);
+    if (!item)
+        return;
     item->setProgress(progress);
 
     const QModelIndex idx = indexFromItem(item);
@@ -87,7 +88,7 @@ void UpdateModel::activityChanged()
 {
     if(ResourcesModel::global()->isFetching()) {
         setResources(QList<AbstractResource*>());
-    } else if(!m_updates->isProgressing()) {
+    } else if(m_updates && !m_updates->isProgressing()) {
         m_updates->prepare();
         setResources(m_updates->toUpdate());
     }
