@@ -31,22 +31,31 @@
 #include <resources/SourcesModel.h>
 #include <Transaction/TransactionModel.h>
 
+#include <QProcess>
 #include <QStringList>
 #include <QDebug>
 #include <QTimer>
 #include <QTimerEvent>
+#include <QStandardPaths>
 
 #include <PackageKit/Transaction>
 #include <PackageKit/Daemon>
 #include <PackageKit/Details>
 
+#include <KDesktopFile>
 #include <KLocalizedString>
 #include <QAction>
 
 #include "utils.h"
+#include "config-paths.h"
 
 MUON_BACKEND_PLUGIN(PackageKitBackend)
 
+static QString locateService(const QString &filename)
+{
+    return QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("applications/")+filename);
+}
+
 PackageKitBackend::PackageKitBackend(QObject* parent)
     : AbstractResourcesBackend(parent)
     , m_updater(new PackageKitUpdater(this))
@@ -90,6 +99,16 @@ PackageKitBackend::PackageKitBackend(QObject* parent)
     connect(updateAction, &QAction::triggered, this, &PackageKitBackend::refreshDatabase);
     m_messageActions += updateAction;
 
+    // Kubuntu-based
+    auto service = locateService(QStringLiteral("software-properties-kde.desktop"));
+    if (!service.isEmpty())
+        m_messageActions += createActionForService(service);
+
+    // openSUSE-based
+    service = locateService(QStringLiteral("YaST2/sw_source.desktop"));
+    if (!service.isEmpty())
+        m_messageActions += createActionForService(service);
+
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::updatesChanged, this, &PackageKitBackend::fetchUpdates);
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::isRunningChanged, this, &PackageKitBackend::checkDaemonRunning);
     connect(m_reviews, &AppstreamReviews::ratingsReady, this, &AbstractResourcesBackend::emitRatingsReady);
@@ -101,6 +120,20 @@ PackageKitBackend::~PackageKitBackend()
 {
 }
 
+QAction* PackageKitBackend::createActionForService(const QString &servicePath)
+{
+    QAction* action = new QAction(this);
+    KDesktopFile parser(servicePath);
+    action->setIcon(QIcon::fromTheme(parser.readIcon()));
+    action->setText(parser.readName());
+    connect(action, &QAction::triggered, action, [servicePath, this](){
+        bool b = QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), {servicePath});
+        if (!b)
+            qWarning() << "Could not start" << servicePath;
+    });
+    return action;
+}
+
 bool PackageKitBackend::isFetching() const
 {
     return m_isFetching;
