@@ -37,18 +37,15 @@ public:
         Security,
         Normal
     };
-    Q_ENUMS(Update)
-    PackageKitNotifier(QObject* parent = nullptr);
+    Q_ENUM(Update)
+    explicit PackageKitNotifier(QObject* parent = nullptr);
     ~PackageKitNotifier() override;
 
     bool isSystemUpToDate() const final;
     uint securityUpdatesCount() final;
     uint updatesCount() final;
-    
-public Q_SLOTS:
-    virtual void configurationChanged();
     void recheckSystemUpdateNeeded() final;
-    
+
 private Q_SLOTS:
     void package(PackageKit::Transaction::Info info, const QString &packageID, const QString &summary);
     void finished(PackageKit::Transaction::Exit exit, uint);
